@@ -1,5 +1,5 @@
 package Net::Stripe;
-$Net::Stripe::VERSION = '0.31';
+$Net::Stripe::VERSION = '0.32';
 use Moose;
 use Class::Load;
 use Kavorka;
@@ -192,7 +192,7 @@ Cards: {
         return $self->_get("customers/$customer/cards/$card_id");
     }
 
-    method get_cards(Net::Stripe::Customer|Str $customer,
+    method get_cards(Net::Stripe::Customer|Str :$customer,
                      HashRef :$created?,
                      Str :$ending_before?,
                      Int :$limit?,
@@ -201,8 +201,8 @@ Cards: {
             $customer = $customer->id;
         }
 
-        $self->_get_collections('cards',
-                                id => $customer,
+        $self->_get_collections("customers/$customer/sources",
+                                object => "card",
                                 created => $created,
                                 ending_before => $ending_before,
                                 limit => $limit,
@@ -595,6 +595,9 @@ sub _get_collections {
     if (my $c = $args{customer}) {
         push @path_args, "customer=$c";
     }
+    if (my $c = $args{object}) {
+        push @path_args, "object=$c";
+    }
 
     # example: $Stripe->get_charges( 'count' => 100, 'created' => { 'gte' => 1397663381 } );
     if (defined($args{created})) {
@@ -733,7 +736,7 @@ Net::Stripe - API client for Stripe.com
 
 =head1 VERSION
 
-version 0.31
+version 0.32
 
 =head1 SYNOPSIS
 
@@ -784,6 +787,54 @@ You can set this to true to see the actual network requests.
 
 =back
 
+=head1 ATTRIBUTES
+
+=head2 api_base
+
+Reader: api_base
+
+Type: Str
+
+Additional documentation: This is the base part of the URL for every request made
+
+=head2 api_key
+
+Reader: api_key
+
+Type: Str
+
+This attribute is required.
+
+Additional documentation: You get this from your Stripe Account settings
+
+=head2 debug
+
+Reader: debug
+
+Writer: debug
+
+Type: Bool
+
+Additional documentation: The debug flag
+
+=head2 debug_network
+
+Reader: debug_network
+
+Writer: debug_network
+
+Type: Bool
+
+Additional documentation: The debug network request flag
+
+=head2 ua
+
+Reader: ua
+
+Type: Object
+
+Additional documentation: The LWP::UserAgent that is used for requests
+
 =head1 Balance Transaction Methods
 
 =head2 get_balance_transaction
