@@ -1,5 +1,5 @@
 package Net::Stripe::Coupon;
-$Net::Stripe::Coupon::VERSION = '0.31';
+$Net::Stripe::Coupon::VERSION = '0.32';
 use Moose;
 use Moose::Util::TypeConstraints;
 use Kavorka;
@@ -36,7 +36,61 @@ Net::Stripe::Coupon - represent a Coupon object from Stripe
 
 =head1 VERSION
 
-version 0.31
+version 0.32
+
+=head1 ATTRIBUTES
+
+=head2 duration
+
+Reader: duration
+
+Writer: duration
+
+Type: Maybe[Str]
+
+This attribute is required.
+
+=head2 duration_in_months
+
+Reader: duration_in_months
+
+Writer: duration_in_months
+
+Type: Maybe[Int]
+
+=head2 id
+
+Reader: id
+
+Writer: id
+
+Type: Maybe[Str]
+
+=head2 max_redemptions
+
+Reader: max_redemptions
+
+Writer: max_redemptions
+
+Type: Maybe[Int]
+
+=head2 percent_off
+
+Reader: percent_off
+
+Writer: percent_off
+
+Type: Maybe[Int]
+
+This attribute is required.
+
+=head2 redeem_by
+
+Reader: redeem_by
+
+Writer: redeem_by
+
+Type: Maybe[Int]
 
 =head1 AUTHORS
 
