@@ -1,5 +1,5 @@
 package Net::Stripe::Discount;
-$Net::Stripe::Discount::VERSION = '0.31';
+$Net::Stripe::Discount::VERSION = '0.32';
 use Moose;
 use Moose::Util::TypeConstraints;
 use Kavorka;
@@ -23,7 +23,25 @@ Net::Stripe::Discount - represent a Discount object from Stripe
 
 =head1 VERSION
 
-version 0.31
+version 0.32
+
+=head1 ATTRIBUTES
+
+=head2 coupon
+
+Reader: coupon
+
+Writer: coupon
+
+Type: Maybe[Net::Stripe::Coupon]
+
+=head2 start
+
+Reader: start
+
+Writer: start
+
+Type: Maybe[Int]
 
 =head1 AUTHORS
 
