@@ -1,5 +1,5 @@
 package Net::Stripe::Refund;
-$Net::Stripe::Refund::VERSION = '0.31';
+$Net::Stripe::Refund::VERSION = '0.32';
 use Moose;
 use Kavorka;
 extends 'Net::Stripe::Resource';
@@ -42,7 +42,75 @@ Net::Stripe::Refund - represent a Refund object from Stripe
 
 =head1 VERSION
 
-version 0.31
+version 0.32
+
+=head1 ATTRIBUTES
+
+=head2 amount
+
+Reader: amount
+
+Type: Maybe[Int]
+
+=head2 balance_transaction
+
+Reader: balance_transaction
+
+Type: Maybe[Str]
+
+=head2 charge
+
+Reader: charge
+
+Type: Maybe[Str]
+
+=head2 created
+
+Reader: created
+
+Type: Maybe[Int]
+
+=head2 currency
+
+Reader: currency
+
+Type: Maybe[Str]
+
+=head2 description
+
+Reader: description
+
+Type: Maybe[Str]
+
+=head2 id
+
+Reader: id
+
+Type: Maybe[Str]
+
+=head2 metadata
+
+Reader: metadata
+
+Type: Maybe[HashRef]
+
+=head2 reason
+
+Reader: reason
+
+Type: Maybe[Str]
+
+=head2 receipt_number
+
+Reader: receipt_number
+
+Type: Maybe[Str]
+
+=head2 refund_application_fee
+
+Reader: refund_application_fee
+
+Type: Maybe[Bool|Object]
 
 =head1 AUTHORS
 
